#
# spec file for package python-treq
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-treq
Version:        20.3.0
Release:        lp152.1.1
Summary:        HTTP library inspired by python-requests
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/twisted/treq
Source:         https://files.pythonhosted.org/packages/source/t/treq/treq-%{version}.tar.gz
BuildRequires:  %{python_module Twisted >= 16.4.0}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module httpbin}
BuildRequires:  %{python_module incremental}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module requests >= 2.1.0}
BuildRequires:  %{python_module service_identity}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Twisted >= 18.7.0
Requires:       python-attrs
Requires:       python-incremental
Requires:       python-requests >= 2.1.0
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
treq is an HTTP library inspired by requests but written on top of Twisted’s Agents.
It provides a simple, higher level API for making HTTP requests when using Twisted.

%prep
%setup -q -n treq-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/treq

%check
export PYTHONDONTWRITEBYTECODE=1
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} %{_bindir}/trial-%{$python_bin_suffix} treq

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/treq
%{python_sitelib}/treq-%{version}-py*.egg-info/

%changelog
* Wed Mar 25 2020 pgajdos@suse.com
- version update to 20.3.0
  - Python 3.7 support. (`#228 <https://github.com/twisted/treq/issues/228>`__)
  - `treq.testing.RequestTraversalAgent` now passes its memory reactor to the `twisted.web.server.Site` it creates, preventing the ``Site`` from polluting the global reactor. (`#225 <https://github.com/twisted/treq/issues/225>`__)
  - `treq.testing` no longer generates deprecation warnings about ``twisted.test.proto_helpers.MemoryReactor``. (`#253 <https://github.com/twisted/treq/issues/253>`__)
  - The ``download_file.py`` example has been updated to do a streaming download with *unbuffered=True*. (`#233 <https://github.com/twisted/treq/issues/233>`__)
  - The *agent* parameter to `treq.request()` has been documented. (`#235 <https://github.com/twisted/treq/issues/235>`__)
  - The type of the *headers* element of a response tuple passed to `treq.testing.RequestSequence` is now correctly documented as `str`. (`#237 <https://github.com/twisted/treq/issues/237>`__)
  - Drop support for Python 3.4. (`#240 <https://github.com/twisted/treq/issues/240>`__)
  - `#247 <https://github.com/twisted/treq/issues/247>`__, `#248 <https://github.com/twisted/treq/issues/248>`__, `#249 <https://github.com/twisted/treq/issues/249>`__
- deleted patches
  - python37.patch (upstreamed)
  - urlparsing.patch (upstreamed)
* Fri Oct  4 2019 Aleksa Sarai <asarai@suse.com>
- Add service_identity BuildRequires so the integration tests don't fail on
  Leap (required for boo#1153017).
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with new Twisted releases:
  * urlparsing.patch
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix testrun on python3.7:
  * python37.patch
- Fix macro expansion to run the tests under python3
* Mon Oct 22 2018 Tomáš Chvátal <tchvatal@suse.com>
- Make the tests actually execute
* Sun Oct 14 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary (rpmlint).
* Thu Oct 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- State all dependnecies properly and execute tests
* Sat Oct  6 2018 ecsos@opensuse.org
- initial version 18.6.0
